==> aroundme-0_4_0.zip: aroundme_0_4_0/www/aroundme_0_4_0/template/am_default/sn_menu.inc.tpl.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of aroundme
// 
// Copyright (C) 2003, 2005 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
// 
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
// 
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
// 
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
// 02111-1307, USA.
// -----------------------------------------------------------------------

?>


<table border="0" cellspacing="0" cellpadding="4" width="100%">
	<tr>
		<td class="txt_title">
			<?php echo $lang['section_menu'];?><br />
			<hr />
		</td>
	</tr>
	<tr>
		<td valign="top" class="txt_sub_menu_on">
			<?php
			if ($page_name_short == "sn_network") {
			?>
			<span class="txt_sub_menu_on"><?php echo $lang['menu_social_network'];?></span><br />
			<?php
			} else {
			?>
			<a href="sn_network.php" class="txt_sub_menu"><?php echo $lang['menu_social_network'];?></a><br />
			<?php }?>


			<?php
			if ($page_name_short == "sn_invite") {
			?>
			<span class="txt_sub_menu_on"><?php echo $lang['menu_invite_friends'];?></span><br />
			<?php
			} else {
			?>
			<a href="sn_invite.php" class="txt_sub_menu"><?php echo $lang['menu_invite_friends'];?></a><br />
			<?php }?>


			<?php
			if ($page_name_short == "sn_statistics") {
			?>
			<span class="txt_sub_menu_on"><?php echo $lang['menu_statistics'];?></span><br />
			<?php
			} else {
			?>
			<a href="sn_statistics.php" class="txt_sub_menu"><?php echo $lang['menu_statistics'];?></a><br />
			<?php }?>
			
			<?php
			if ($page_name_short == "sn_blocked") {
			?>
			<span class="txt_sub_menu_on"><?php echo $lang['menu_blocked_users'];?></span><br />
			<?php
			} else {
			?>
			<a href="sn_blocked.php" class="txt_sub_menu"><?php echo $lang['menu_blocked_users'];?></a><br />
			<?php }?>
		</td>
	</tr>
</table>

<?php
if (isset($profile['profile_id'])) {
?>

<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="10" alt="" /><br />
		
<table border="0" cellspacing="0" cellpadding="4" width="100%">
	<tr>
		<td class="txt_title">
			<?php echo $lang['section_member'];?><br />
			<hr />
		</td>
	</tr>
	<tr>
		<td>
			<?php
			if ($page_name_short == "sn_profile") {
			?>
			<span class="txt_sub_menu_on"><?php echo $lang['menu_profile'];?></span><br />
			<?php
			} else {
			?>
			<a href="sn_profile.php?user_id=<?php echo $profile['user_id'];?>" class="txt_sub_menu"><?php echo $lang['menu_profile'];?></a><br />
			<?php }?>


			<?php
			if ($page_name_short == "sn_blog") {
			?>
			<span class="txt_sub_menu_on"><?php echo $lang['menu_blog'];?></span><br />
			<?php
			} else {
			?>
			<a href="sn_blog.php?user_id=<?php echo $profile['user_id'];?>" class="txt_sub_menu"><?php echo $lang['menu_blog'];?></a><br />
			<?php }?>


			<?php
			if ($page_name_short == "sn_library") {
			?>
			<span class="txt_sub_menu_on"><?php echo $lang['menu_library'];?></span><br />
			<?php
			} else {
			?>
			<a href="sn_library.php?user_id=<?php echo $profile['user_id'];?>" class="txt_sub_menu"><?php echo $lang['menu_library'];?></a><br />
			<?php }?>


			<?php
			if ($page_name_short == "sn_friends") {
			?>
			<span class="txt_sub_menu_on"><?php echo $lang['menu_friends'];?></span><br />
			<?php
			} else {
			?>
			<a href="sn_friends.php?user_id=<?php echo $profile['user_id'];?>" class="txt_sub_menu"><?php echo $lang['menu_friends'];?></a><br />
			<?php }?>


			<?php
			if ($page_name_short == "sn_publishing") {
			?>
			<span class="txt_sub_menu_on"><?php echo $lang['menu_publishing'];?></span><br />
			<?php
			} else {
			?>
			<a href="sn_publishing.php?user_id=<?php echo $profile['user_id'];?>" class="txt_sub_menu"><?php echo $lang['menu_publishing'];?></a><br />
			<?php }?>


			<?php
			if ($page_name_short == "sn_recommended") {
			?>
			<span class="txt_sub_menu_on"><?php echo $lang['menu_recommended'];?></span><br />
			<?php
			} else {
			?>
			<a href="sn_recommended.php?user_id=<?php echo $profile['user_id'];?>" class="txt_sub_menu"><?php echo $lang['menu_recommended'];?></a><br />
			<?php }?>
			
			<?php
			if (isset($profile['profile_allow_msg']) && $profile['profile_allow_msg'] == 1) {
			?>
			<a href="msg_compose.php?to_user_id=<?php echo $profile['user_id'];?>" class="txt_sub_menu"><?php echo $lang['menu_send_message'];?></a><br />
			<?php }?>
			
		</td>
	</tr>
</table>
<?php
}
?>

==> aroundme_0_4_1.zip: aroundme_0_4_1/www/aroundme_0_4_1/template/am_default/sn_menu.inc.tpl.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of aroundme
// 
// Copyright (C) 2003, 2005 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
// 
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
// 
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
// 
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
// 02111-1307, USA.
// -----------------------------------------------------------------------

?>


<table border="0" cellspacing="0" cellpadding="4" width="100%">
	<tr>
		<td class="txt_title">
			<?php echo $lang['section_menu'];?><br />
			<hr />
		</td>
	</tr>
	<tr>
		<td valign="top" class="txt_sub_menu_on">
			<?php
			if ($page_name_short == "sn_network") {
			?>
			<span class="txt_sub_menu_on"><?php echo $lang['menu_social_network'];?></span><br />
			<?php
			} else {
			?>
			<a href="sn_network.php" class="txt_sub_menu"><?php echo $lang['menu_social_network'];?></a><br />
			<?php }?>


			<?php
			if ($page_name_short == "sn_invite") {
			?>
			<span class="txt_sub_menu_on"><?php echo $lang['menu_invite_friends'];?></span><br />
			<?php
			} else {
			?>
			<a href="sn_invite.php" class="txt_sub_menu"><?php echo $lang['menu_invite_friends'];?></a><br />
			<?php }?>


			<?php
			if ($page_name_short == "sn_statistics") {
			?>
			<span class="txt_sub_menu_on"><?php echo $lang['menu_statistics'];?></span><br />
			<?php
			} else {
			?>
			<a href="sn_statistics.php" class="txt_sub_menu"><?php echo $lang['menu_statistics'];?></a><br />
			<?php }?>
			
			<?php
			if ($page_name_short == "sn_blocked") {
			?>
			<span class="txt_sub_menu_on"><?php echo $lang['menu_blocked_users'];?></span><br />
			<?php
			} else {
			?>
			<a href="sn_blocked.php" class="txt_sub_menu"><?php echo $lang['menu_blocked_users'];?></a><br />
			<?php }?>
		</td>
	</tr>
</table>

<?php
if (isset($profile['profile_id'])) {
?>

<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="10" alt="" /><br />
		
<table border="0" cellspacing="0" cellpadding="4" width="100%">
	<tr>
		<td class="txt_title">
			<?php echo $lang['section_member'];?><br />
			<hr />
		</td>
	</tr>
	<tr>
		<td>
			<?php
			if ($page_name_short == "sn_profile") {
			?>
			<span class="txt_sub_menu_on"><?php echo $lang['menu_profile'];?></span><br />
			<?php
			} else {
			?>
			<a href="sn_profile.php?user_id=<?php echo $profile['user_id'];?>" class="txt_sub_menu"><?php echo $lang['menu_profile'];?></a><br />
			<?php }?>


			<?php
			if ($page_name_short == "sn_blog") {
			?>
			<span class="txt_sub_menu_on"><?php echo $lang['menu_blog'];?></span><br />
			<?php
			} else {
			?>
			<a href="sn_blog.php?user_id=<?php echo $profile['user_id'];?>" class="txt_sub_menu"><?php echo $lang['menu_blog'];?></a><br />
			<?php }?>


			<?php
			if ($page_name_short == "sn_library") {
			?>
			<span class="txt_sub_menu_on"><?php echo $lang['menu_library'];?></span><br />
			<?php
			} else {
			?>
			<a href="sn_library.php?user_id=<?php echo $profile['user_id'];?>" class="txt_sub_menu"><?php echo $lang['menu_library'];?></a><br />
			<?php }?>


			<?php
			if ($this->user_acs->checkPermission($resource_ids['social_network'], $privilege_ids['allow_access'])) { //resourece_id, Priv_id
			if ($page_name_short == "sn_friends") {
			?>
			<span class="txt_sub_menu_on"><?php echo $lang['menu_friends'];?></span><br />
			<?php
			} else {
			?>
			<a href="sn_friends.php?user_id=<?php echo $profile['user_id'];?>" class="txt_sub_menu"><?php echo $lang['menu_friends'];?></a><br />
			<?php }}?>


			<?php
			if ($page_name_short == "sn_publishing") {
			?>
			<span class="txt_sub_menu_on"><?php echo $lang['menu_publishing'];?></span><br />
			<?php
			} else {
			?>
			<a href="sn_publishing.php?user_id=<?php echo $profile['user_id'];?>" class="txt_sub_menu"><?php echo $lang['menu_publishing'];?></a><br />
			<?php }?>


			<?php
			if ($page_name_short == "sn_recommended") {
			?>
			<span class="txt_sub_menu_on"><?php echo $lang['menu_recommended'];?></span><br />
			<?php
			} else {
			?>
			<a href="sn_recommended.php?user_id=<?php echo $profile['user_id'];?>" class="txt_sub_menu"><?php echo $lang['menu_recommended'];?></a><br />
			<?php }?>
			
			<?php
			if (isset($profile['profile_allow_msg']) && $profile['profile_allow_msg'] == 1) {
			?>
			<a href="msg_compose.php?to_user_id=<?php echo $profile['user_id'];?>" class="txt_sub_menu"><?php echo $lang['menu_send_message'];?></a><br />
			<?php }?>
			
		</td>
	</tr>
</table>
<?php
}
?>
